@@ -43,7 +43,9 @@ DoCopyFileWorker::~DoCopyFileWorker()
 // main thread using
 void DoCopyFileWorker::pause()
 {
-    state = kPasued;
+    if (state == kPaused || state == kStopped)
+        return;
+    state = kPaused;
 }
 // main thread using
 void DoCopyFileWorker::resume()
@@ -54,7 +56,7 @@ void DoCopyFileWorker::resume()
 // main thread using// main thread using
 void DoCopyFileWorker::stop()
 {
-    state = kStoped;
+    state = kStopped;
     waitCondition->wakeAll();
     auto fileOpsAll = fileOps.listByLock();
     for (auto op : fileOpsAll) {
@@ -227,7 +229,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFilePractically(const DFileInfo
         setTargetPermissions(fromInfo->uri(), toInfo->uri());
         workData->zeroOrlinkOrDirWriteSize += FileUtils::getMemoryPageSize();
         FileUtils::notifyFileChangeManual(DFMBASE_NAMESPACE::Global::FileNotifyType::kFileAdded, toInfo->uri());
-        if (workData->exBlockSyncEveryWrite || ProtocolUtils::isSMBFile(toInfo->uri()))
+        if (shouldSyncToDevice(toInfo))
             syncBlockFile(toInfo);
         return NextDo::kDoCopyNext;
     }
@@ -237,7 +239,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFilePractically(const DFileInfo
     // 循环读取和写入文件，拷贝
     int toFd = -1;
     auto toIsSmb = ProtocolUtils::isSMBFile(toInfo->uri());
-    if (workData->exBlockSyncEveryWrite || toIsSmb)
+    if (shouldSyncToDevice(toIsSmb))
         toFd = open(toInfo->uri().path().toUtf8().toStdString().data(), O_RDONLY);
     qint64 blockSize = fromSize > kMaxBufferLength ? kMaxBufferLength : fromSize;
     char *data = new char[static_cast<uint>(blockSize + 1)];
@@ -267,7 +269,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFilePractically(const DFileInfo
         }
 
         // 执行同步策略
-        if ((workData->exBlockSyncEveryWrite || toIsSmb) && toFd > 0)
+        if (shouldSyncToDevice(toIsSmb) && toFd > 0)
             syncfs(toFd);
 
     } while (fromDevice->pos() != fromSize);
@@ -276,7 +278,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFilePractically(const DFileInfo
     data = nullptr;
 
     // 执行同步策略
-    if ((workData->exBlockSyncEveryWrite || toIsSmb) && toFd > 0)
+    if (shouldSyncToDevice(toIsSmb) && toFd > 0)
         syncfs(toFd);
 
     if (toFd > 0)
@@ -332,7 +334,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFileByRange(const DFileInfoPoin
         setTargetPermissions(fromInfo->uri(), toInfo->uri());
         workData->zeroOrlinkOrDirWriteSize += FileUtils::getMemoryPageSize();
         FileUtils::notifyFileChangeManual(DFMBASE_NAMESPACE::Global::FileNotifyType::kFileAdded, toInfo->uri());
-        if (workData->exBlockSyncEveryWrite || ProtocolUtils::isSMBFile(toInfo->uri()))
+        if (shouldSyncToDevice(toInfo))
             syncfs(targetFd);
         return NextDo::kDoCopyNext;
     }
@@ -340,8 +342,8 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFileByRange(const DFileInfoPoin
     size_t blockSize = static_cast<size_t>(fromSize > kMaxBufferLength ? kMaxBufferLength : fromSize);
     off_t offset_in = 0;
     off_t offset_out = 0;
+    size_t total = static_cast<size_t>(fromSize);
     ssize_t result = -1;
-    size_t left = static_cast<size_t>(fromSize);
     AbstractJobHandler::SupportAction action { AbstractJobHandler::SupportAction::kNoAction };
     do {
         if (Q_UNLIKELY(!stateCheck()))
@@ -349,7 +351,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFileByRange(const DFileInfoPoin
         do {
             if (Q_UNLIKELY(!stateCheck()))
                 return NextDo::kDoCopyErrorAddCancel;
-            blockSize = left < blockSize ? left : blockSize;
+            blockSize = total < blockSize ? total : blockSize;
             result = copy_file_range(sourcFd, &offset_in, targetFd, &offset_out, blockSize, 0);
             if (result < 0) {
                 auto lastError = strerror(errno);
@@ -362,7 +364,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFileByRange(const DFileInfoPoin
                 offset_out = offset_in;
             } else {
                 workData->currentWriteSize += result;
-                left -= static_cast<size_t>(result);
+                total -= static_cast<size_t>(result);
             }
         } while (action == AbstractJobHandler::SupportAction::kRetryAction && !isStopped());
         checkRetry();
@@ -380,7 +382,7 @@ DoCopyFileWorker::NextDo DoCopyFileWorker::doCopyFileByRange(const DFileInfoPoin
 
 bool DoCopyFileWorker::stateCheck()
 {
-    if (state == kPasued)
+    if (state == kPaused)
         workerWait();
 
     return state == kNormal;
@@ -854,7 +856,7 @@ void DoCopyFileWorker::checkRetry()
 
 bool DoCopyFileWorker::isStopped()
 {
-    return state == kStoped;
+    return state == kStopped;
 }
 
 /*!
@@ -872,7 +874,27 @@ void DoCopyFileWorker::setTargetPermissions(const QUrl &fromUrl, const QUrl &toU
     localFileHandler->setFileTime(toInfo->urlOf(UrlInfoType::kUrl), fromInfo->timeOf(TimeInfoType::kLastRead).value<QDateTime>(), fromInfo->timeOf(TimeInfoType::kLastModified).value<QDateTime>());
     QFileDevice::Permissions permissions = fromInfo->permissions();
     QString path = fromInfo->urlOf(UrlInfoType::kUrl).path();
-    //权限为0000时，源文件已经被删除，无需修改新建的文件的权限为0000
+    // 权限为0000时，源文件已经被删除，无需修改新建的文件的权限为0000
     if (permissions != 0000)
         localFileHandler->setPermissions(toInfo->urlOf(UrlInfoType::kUrl), permissions);
 }
+
+/*!
+ * \brief DoCopyFileWorker::shouldSyncToDevice Check if sync to device is needed
+ * \param toInfo Target file info
+ * \return true if sync is required, false otherwise
+ */
+bool DoCopyFileWorker::shouldSyncToDevice(const DFileInfoPointer &toInfo) const
+{
+    return shouldSyncToDevice(ProtocolUtils::isSMBFile(toInfo->uri()));
+}
+
+/*!
+ * \brief DoCopyFileWorker::shouldSyncToDevice Check if sync to device is needed (optimized version)
+ * \param toIsSmb Whether target is SMB file (pre-calculated for performance)
+ * \return true if sync is required, false otherwise
+ */
+bool DoCopyFileWorker::shouldSyncToDevice(bool toIsSmb) const
+{
+    return workData->expandDiskSync && (workData->exBlockSyncEveryWrite || toIsSmb);
+}
