@@ -57,15 +57,15 @@ QString FileOperationsEventReceiver::newDocmentName(const QUrl &url,
         break;
     case CreateFileType::kCreateFileTypeWord:
         baseName = QObject::tr("Document");
-        suffixex = "doc";
+        suffixex = "docx";
         break;
     case CreateFileType::kCreateFileTypeExcel:
         baseName = QObject::tr("Spreadsheet");
-        suffixex = "xls";
+        suffixex = "xlsx";
         break;
     case CreateFileType::kCreateFileTypePowerpoint:
         baseName = QObject::tr("Presentation");
-        suffixex = "ppt";
+        suffixex = "pptx";
         break;
     case CreateFileType::kCreateFileTypeDefault:
         baseName = QObject::tr("New File");
