@@ -6,6 +6,7 @@
 #include "views/optionbuttonbox.h"
 #include "events/titlebareventcaller.h"
 #include "utils/optionbuttonmanager.h"
+#include "utils/titlebarhelper.h"
 #include "views/sortbybutton.h"
 #include "views/viewoptionsbutton.h"
 
@@ -77,9 +78,8 @@ void OptionButtonBoxPrivate::setViewMode(ViewMode mode)
 
 void OptionButtonBoxPrivate::loadViewMode(const QUrl &url)
 {
-    QUrl tmpUrl = url.adjusted(QUrl::RemoveQuery);
-    auto defaultViewMode = static_cast<int>(TitleBarEventCaller::sendGetDefualtViewMode(tmpUrl.scheme()));
-    auto viewMode = static_cast<ViewMode>(Application::appObtuselySetting()->value("FileViewState", tmpUrl).toMap().value("viewMode", defaultViewMode).toInt());
+    auto defaultViewMode = static_cast<int>(TitleBarEventCaller::sendGetDefualtViewMode(url.scheme()));
+    auto viewMode = static_cast<ViewMode>(TitleBarHelper::getFileViewStateValue(url, "viewMode", defaultViewMode).toInt());
     if (viewMode == ViewMode::kTreeMode && !DConfigManager::instance()->value(kViewDConfName, kTreeViewEnable, true).toBool()) {
         fmInfo() << "Tree view is disabled in config, switching to list mode";
         viewMode = ViewMode::kListMode;
@@ -114,7 +114,7 @@ void OptionButtonBoxPrivate::switchMode(ViewMode mode)
 
 void OptionButtonBoxPrivate::onViewModeChanged(int mode)
 {
-    if (Application::appObtuselySetting()->value("FileViewState", currentUrl).toMap().contains("viewMode")) {
+    if (!TitleBarHelper::getFileViewStateValue(currentUrl, "viewMode").isNull()) {
         loadViewMode(currentUrl);
     } else {
         auto viewMode = static_cast<ViewMode>(mode);
@@ -263,6 +263,7 @@ void OptionButtonBox::initializeUi()
     d->iconViewButton->setFixedSize(buttonSize);
     d->iconViewButton->setToolTip(tr("Icon view"));
     d->iconViewButton->setIconSize(buttonIconSize);
+    d->iconViewButton->setFocusPolicy(Qt::NoFocus);
 
     d->listViewButton = new CustomDToolButton;
     d->listViewButton->setCheckable(true);
@@ -270,6 +271,7 @@ void OptionButtonBox::initializeUi()
     d->listViewButton->setFixedSize(buttonSize);
     d->listViewButton->setToolTip(tr("List view"));
     d->listViewButton->setIconSize(buttonIconSize);
+    d->listViewButton->setFocusPolicy(Qt::NoFocus);
     d->buttonGroup->addButton(d->iconViewButton);
     d->buttonGroup->addButton(d->listViewButton);
 
@@ -281,6 +283,7 @@ void OptionButtonBox::initializeUi()
         d->treeViewButton->setFixedSize(buttonSize);
         d->treeViewButton->setToolTip(tr("Tree view"));
         d->treeViewButton->setIconSize(buttonIconSize);
+        d->treeViewButton->setFocusPolicy(Qt::NoFocus);
         d->buttonGroup->addButton(d->treeViewButton);
     } else {
         fmDebug() << "Tree view is disabled in configuration";
@@ -388,15 +391,23 @@ void OptionButtonBox::initUiForSizeMode()
     d->hBoxLayout = new QHBoxLayout;
     d->hBoxLayout->setSpacing(0);
     d->hBoxLayout->setContentsMargins(0, 0, 0, 0);
+
+    // Add compact button (for compact mode)
     d->hBoxLayout->addWidget(d->compactButton);
     d->hBoxLayout->addSpacing(10);
+
+    // Add view mode buttons (left side)
     d->hBoxLayout->addWidget(d->iconViewButton);
     d->hBoxLayout->addWidget(d->listViewButton);
     if (d->treeViewButton) {
         d->hBoxLayout->addWidget(d->treeViewButton);
     }
     d->hBoxLayout->addWidget(d->viewOptionsButton);
-    d->hBoxLayout->addSpacing(10);
+
+    // Add stretch to push sortByButton to the right and keep its position fixed
+    d->hBoxLayout->addStretch(1);
+
+    // Add sortByButton (right side - position will remain fixed)
     d->hBoxLayout->addWidget(d->sortByButton);
 
     setLayout(d->hBoxLayout);
@@ -404,20 +415,33 @@ void OptionButtonBox::initUiForSizeMode()
 
 void OptionButtonBox::updateFixedWidth()
 {
-    int fixedWidth = 10;   // 起始间距
+    int fixedWidth = 10;   // Initial spacing
 
-    // 视图模式按钮部分
+    // View mode buttons section (left side)
     if (d->isCompactMode) {
-        fixedWidth += d->compactButton->width();
+        fixedWidth += 48;   // Compact button width
+        fixedWidth += 10;   // Spacing after compact button
     } else {
-        fixedWidth += d->iconViewButton->width() + d->listViewButton->width();
-        if (d->treeViewButton) {
+        fixedWidth += 10;   // Spacing after compact button, using their actual width
+        // Only count visible view mode buttons (each is kToolButtonSize = 30)
+        if (d->iconViewEnabled && d->iconViewButton && !d->iconViewButton->isHidden())
+            fixedWidth += d->iconViewButton->width();
+        if (d->listViewEnabled && d->listViewButton && !d->listViewButton->isHidden())
+            fixedWidth += d->listViewButton->width();
+        if (d->treeViewEnabled && d->treeViewButton && !d->treeViewButton->isHidden())
             fixedWidth += d->treeViewButton->width();
-        }
     }
 
-    // 其他按钮部分（这部分在两种模式下都是一样的）
-    fixedWidth += d->viewOptionsButton->width() + 10 + d->sortByButton->width();
+    // ViewOptions button (part of left side, also kToolButtonSize = 30)
+    if (d->viewOptionsEnabled && d->viewOptionsButton && !d->viewOptionsButton->isHidden())
+        fixedWidth += kToolButtonSize;
+
+    // Minimum spacing for stretch area (to ensure sortByButton stays on right)
+    fixedWidth += 20;   // Minimum stretch space
+
+    // SortByButton (right side - width is 46 when visible)
+    if (d->sortByEnabled && d->sortByButton && !d->sortByButton->isHidden())
+        fixedWidth += 46;   // kSortToolButtonWidth
 
     setFixedWidth(fixedWidth);
 }
