@@ -46,7 +46,6 @@ FileSortWorker::FileSortWorker(const QUrl &url, const QString &key, FileViewFilt
     if (!dirPath.isEmpty() && dirPath != QDir::separator() && url.path().endsWith(QDir::separator()))
         dirPath.chop(1);
     current.setPath(dirPath);
-    sortAndFilter = SortFilterFactory::create<AbstractSortFilter>(current);
     isMixDirAndFile = Application::instance()->appAttribute(Application::kFileAndDirMixedSort).toBool();
 
     fmDebug() << "Mixed dir and file sorting enabled:" << isMixDirAndFile;
@@ -126,8 +125,11 @@ QUrl FileSortWorker::mapToIndex(int index)
 {
     QReadLocker lk(&locker);
 
-    if (index < 0 || index >= visibleChildren.count())
+    if (index < 0 || index >= visibleChildren.count()) {
+        fmDebug() << "Invalid index for mapToIndex:" << index << "visible children count:" << visibleChildren.count();
         return QUrl();
+    }
+
     return visibleChildren.at(index);
 }
 
@@ -158,8 +160,10 @@ FileItemDataPointer FileSortWorker::childData(const int index)
     QUrl url;
     {
         QReadLocker lk(&locker);
-        if (index < 0 || index >= visibleChildren.count())
+        if (index < 0 || index >= visibleChildren.count()) {
+            fmDebug() << "Invalid index for childData:" << index << "visible children count:" << visibleChildren.count();
             return nullptr;
+        }
         url = visibleChildren.at(index);
     }
 
@@ -169,6 +173,7 @@ FileItemDataPointer FileSortWorker::childData(const int index)
 
 void FileSortWorker::cancel()
 {
+    fmDebug() << "Canceling FileSortWorker operations";
     isCanceled = true;
     mimeSorting = false;
 }
@@ -182,6 +187,7 @@ int FileSortWorker::getChildShowIndex(const QUrl &url)
 QList<QUrl> FileSortWorker::getChildrenUrls()
 {
     QReadLocker lk(&locker);
+    fmDebug() << "Getting children URLs, count:" << visibleChildren.size();
     return visibleChildren;
 }
 
@@ -394,7 +400,7 @@ void FileSortWorker::handleWatcherAddChildren(const QList<SortInfoPointer> &chil
             continue;
         }
 
-        auto suc = addChild(sortInfo, AbstractSortFilter::SortScenarios::kSortScenariosWatcherAddFile);
+        auto suc = addChild(sortInfo, SortScenarios::kSortScenariosWatcherAddFile);
         if (!added)
             added = suc;
     }
@@ -625,7 +631,7 @@ bool FileSortWorker::handleUpdateFile(const QUrl &url)
         auto subVisibleList = visibleTreeChildren.take(parentUrl);
         auto offset = subVisibleList.count();
         if (orgSortRole != Global::ItemRoles::kItemDisplayRole)
-            offset = insertSortList(sortInfo->fileUrl(), subVisibleList, AbstractSortFilter::SortScenarios::kSortScenariosWatcherAddFile);
+            offset = insertSortList(sortInfo->fileUrl(), subVisibleList, SortScenarios::kSortScenariosWatcherAddFile);
         auto subIndex = offset;
         // 根目录下的offset计算不一样
         if (UniversalUtils::urlEquals(parentUrl, current)) {
@@ -1084,7 +1090,7 @@ void FileSortWorker::filterTreeDirFiles(const QUrl &parent, const bool byInfo)
 }
 
 bool FileSortWorker::addChild(const SortInfoPointer &sortInfo,
-                              const AbstractSortFilter::SortScenarios sort)
+                              const SortScenarios sort)
 {
     if (isCanceled || sortInfo.isNull())
         return false;
@@ -1158,7 +1164,7 @@ bool FileSortWorker::addChild(const SortInfoPointer &sortInfo,
         insertToList(visibleChildren, showIndex, sortInfo->fileUrl());
     }
 
-    if (sort == AbstractSortFilter::SortScenarios::kSortScenariosWatcherAddFile)
+    if (sort == SortScenarios::kSortScenariosWatcherAddFile)
         Q_EMIT selectAndEditFile(sortInfo->fileUrl());
 
     return true;
@@ -1311,7 +1317,7 @@ QList<QUrl> FileSortWorker::sortTreeFiles(const QList<QUrl> &children, const boo
         if (isCanceled)
             return {};
         if (!reverse) {
-            sortIndex = insertSortList(url, sortList, AbstractSortFilter::SortScenarios::kSortScenariosNormal);
+            sortIndex = insertSortList(url, sortList, SortScenarios::kSortScenariosNormal);
         } else if (!firstFile && !isMixDirAndFile) {
             auto sortInfo = sortInfos.value(url);
             if (sortInfo && sortInfo->needsCompletion())
@@ -1503,7 +1509,7 @@ void FileSortWorker::createAndInsertItemData(const int8_t depth, const SortInfoP
 }
 
 int FileSortWorker::insertSortList(const QUrl &needNode, const QList<QUrl> &list,
-                                   AbstractSortFilter::SortScenarios sort)
+                                   SortScenarios sort)
 {
     int begin = 0;
     int end = list.count();
@@ -1546,7 +1552,7 @@ int FileSortWorker::insertSortList(const QUrl &needNode, const QList<QUrl> &list
 }
 
 // 左边比右边小返回true，
-bool FileSortWorker::lessThan(const QUrl &left, const QUrl &right, AbstractSortFilter::SortScenarios sort)
+bool FileSortWorker::lessThan(const QUrl &left, const QUrl &right, SortScenarios sort)
 {
     if (isCanceled)
         return false;
@@ -1562,19 +1568,6 @@ bool FileSortWorker::lessThan(const QUrl &left, const QUrl &right, AbstractSortF
     if (!rightSortInfo)
         return false;
 
-    if (sortAndFilter) {
-        const FileInfoPointer leftInfo = leftItem && leftItem->fileInfo()
-                ? leftItem->fileInfo()
-                : InfoFactory::create<FileInfo>(left);
-        const FileInfoPointer rightInfo = rightItem && rightItem->fileInfo()
-                ? rightItem->fileInfo()
-                : InfoFactory::create<FileInfo>(right);
-        auto result = sortAndFilter->lessThan(leftInfo, rightInfo, isMixDirAndFile,
-                                              orgSortRole, sort);
-        if (result > 0)
-            return result;
-    }
-
     bool isDirLeft = leftSortInfo->isDir();
     bool isDirRight = rightSortInfo->isDir();
 
@@ -1713,10 +1706,6 @@ QVariant FileSortWorker::data(const SortInfoPointer &info, Global::ItemRoles rol
         auto lastModified = QDateTime::fromSecsSinceEpoch(info->lastModifiedTime());
         return lastModified.isValid() ? lastModified.toString(FileUtils::dateTimeFormat()) : "-";
     }
-    case kItemFileCreatedRole: {
-        auto created = QDateTime::fromSecsSinceEpoch(info->createTime());
-        return created.isValid() ? created.toString(FileUtils::dateTimeFormat()) : "-";
-    }
     case kItemFileDisplayNameRole:
         return info->fileUrl().fileName();
     case kItemFileMimeTypeRole: {
@@ -1766,13 +1755,6 @@ bool FileSortWorker::checkFilters(const SortInfoPointer &sortInfo, const bool by
             item->setAvailableState(false);
     }
 
-    // 处理继承
-    if (sortAndFilter) {
-        auto result = sortAndFilter->checkFilters(InfoFactory::create<FileInfo>(sortInfo->fileUrl()), filters, filterData);
-        if (result >= 0)
-            return result;
-    }
-
     if (filters == QDir::NoFilter)
         return true;
 
