@@ -13,6 +13,7 @@
 #include <dfm-base/base/schemefactory.h>
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/base/application/application.h>
+#include <dfm-base/base/application/settings.h>
 #include <dfm-base/utils/universalutils.h>
 
 #include <dfm-framework/dpf.h>
@@ -79,6 +80,7 @@ void WorkspaceHelper::setCustomTopWidgetVisible(quint64 windowId, const QString
 
 void WorkspaceHelper::setFilterData(quint64 windowId, const QUrl &url, const QVariant &data)
 {
+    fmDebug() << "WorkspaceHelper: setting filter data for window" << windowId << "URL" << url.toString();
     FileView *view = findFileViewByWindowID(windowId);
     if (view)
         view->setFilterData(url, data);
@@ -86,6 +88,7 @@ void WorkspaceHelper::setFilterData(quint64 windowId, const QUrl &url, const QVa
 
 void WorkspaceHelper::setFilterCallback(quint64 windowId, const QUrl &url, const FileViewFilterCallback callback)
 {
+    fmDebug() << "WorkspaceHelper: setting filter callback for window" << windowId << "URL" << url.toString();
     FileView *view = findFileViewByWindowID(windowId);
     if (view)
         view->setFilterCallback(url, callback);
@@ -399,6 +402,7 @@ void WorkspaceHelper::laterRequestSelectFiles(const QList<QUrl> &urls)
 
 void WorkspaceHelper::fileUpdate(const QUrl &url)
 {
+    fmDebug() << "WorkspaceHelper: updating file for URL" << url.toString();
     for (const auto &wind : kWorkspaceMap) {
         if (wind) {
             FileView *view = dynamic_cast<FileView *>(wind->currentView());
@@ -551,3 +555,24 @@ FileView *WorkspaceHelper::findFileViewByWindowID(const quint64 windowID)
     fmDebug() << "No workspace widget found for window ID:" << windowID;
     return {};
 }
+
+QUrl WorkspaceHelper::transformViewModeUrl(const QUrl &url) const
+{
+    auto callback = findCustomViewProperty(url.scheme()).viewModelUrlCallback;
+    return callback ? callback(url) : url;
+}
+
+QVariant WorkspaceHelper::getFileViewStateValue(const QUrl &url, const QString &key, const QVariant &defaultValue) const
+{
+    QUrl viewModeUrl = transformViewModeUrl(url);
+    QMap<QString, QVariant> valueMap = Application::appObtuselySetting()->value("FileViewState", viewModeUrl).toMap();
+    return valueMap.value(key, defaultValue);
+}
+
+void WorkspaceHelper::setFileViewStateValue(const QUrl &url, const QString &key, const QVariant &value)
+{
+    QUrl viewModeUrl = transformViewModeUrl(url);
+    QVariantMap map = Application::appObtuselySetting()->value("FileViewState", viewModeUrl).toMap();
+    map[key] = value;
+    Application::appObtuselySetting()->setValue("FileViewState", viewModeUrl, map);
+}
