@@ -128,26 +128,6 @@ int BaseItemDelegate::setIconSizeByIconSizeLevel(int level)
     return -1;
 }
 
-void BaseItemDelegate::setItemMinimumWidthByWidthLevel(int level)
-{
-    Q_UNUSED(level)
-}
-
-int BaseItemDelegate::minimumWidthLevel() const
-{
-    return -1;
-}
-
-void BaseItemDelegate::setItemMinimumHeightByHeightLevel(int level)
-{
-    Q_UNUSED(level)
-}
-
-int BaseItemDelegate::minimumHeightLevel() const
-{
-    return -1;
-}
-
 QModelIndexList BaseItemDelegate::hasWidgetIndexs() const
 {
     Q_D(const BaseItemDelegate);
