@@ -6,6 +6,7 @@
 #include "views/headerview.h"
 #include "views/fileviewstatusbar.h"
 #include "views/baseitemdelegate.h"
+#include "views/iconitemdelegate.h"
 #include "models/fileviewmodel.h"
 #include "utils/workspacehelper.h"
 #include "utils/dragdrophelper.h"
@@ -113,8 +114,13 @@ void FileViewPrivate::initIconModeView()
 
     if (q->itemDelegate()) {
         q->itemDelegate()->setIconSizeByIconSizeLevel(currentIconSizeLevel);
-        q->itemDelegate()->setItemMinimumWidthByWidthLevel(currentGridDensityLevel);
-        fmDebug() << "Item delegate configured for icon mode - density level:" << currentGridDensityLevel;
+        
+        // Set width level only for icon delegate
+        auto iconDelegate = dynamic_cast<IconItemDelegate*>(q->itemDelegate());
+        if (iconDelegate) {
+            iconDelegate->setItemMinimumWidthByWidthLevel(currentGridDensityLevel);
+            fmDebug() << "Item delegate configured for icon mode - density level:" << currentGridDensityLevel;
+        }
     }
 }
 
@@ -123,7 +129,7 @@ void FileViewPrivate::initListModeView()
     fmDebug() << "Initializing list mode view";
 
     if (q->itemDelegate()) {
-        q->itemDelegate()->setItemMinimumHeightByHeightLevel(currentListHeightLevel);
+        q->itemDelegate()->setIconSizeByIconSizeLevel(currentListHeightLevel);
         fmDebug() << "Item delegate height level set to:" << currentListHeightLevel;
     }
 
@@ -206,7 +212,7 @@ void FileViewPrivate::initContentLabel()
         palette.setColor(QPalette::Text, color);
         contentLabel->setPalette(palette);
         QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged,
-                         contentLabel, [this](DGuiApplicationHelper::ColorType themeType){
+                         contentLabel, [this](DGuiApplicationHelper::ColorType themeType) {
                              QColor textColor = (themeType == DGuiApplicationHelper::ColorType::LightType)
                                      ? QColor(0, 0, 0, 102)
                                      : QColor(255, 255, 255, 102);
@@ -268,7 +274,7 @@ void FileViewPrivate::loadViewMode(const QUrl &url)
 
     if (parentViewMode != -1) {
         currentViewMode = static_cast<Global::ViewMode>(parentViewMode);
-    } else if (savedViewMode != -1 && WorkspaceHelper::instance()->isViewModeSupported(url.scheme(), static_cast<Global::ViewMode>(savedViewMode))) {  // saved view mode in old version may not be supported
+    } else if (savedViewMode != -1 && WorkspaceHelper::instance()->isViewModeSupported(url.scheme(), static_cast<Global::ViewMode>(savedViewMode))) {   // saved view mode in old version may not be supported
         currentViewMode = static_cast<Global::ViewMode>(savedViewMode);
         fmDebug() << "Using saved view mode:" << savedViewMode;
     } else {
@@ -289,8 +295,7 @@ void FileViewPrivate::loadViewMode(const QUrl &url)
 
 QVariant FileViewPrivate::fileViewStateValue(const QUrl &url, const QString &key, const QVariant &defalutValue)
 {
-    QMap<QString, QVariant> valueMap = Application::appObtuselySetting()->value("FileViewState", url).toMap();
-    return valueMap.value(key, defalutValue);
+    return WorkspaceHelper::instance()->getFileViewStateValue(url, key, defalutValue);
 }
 
 void FileViewPrivate::updateHorizontalOffset()
